@@ -183,7 +183,7 @@ struct c_block *f,*t;               // f (from) is source pointer
 
                                     // only sidebands that are present in both the from-list
                                     // and the to-list are present in the resulting to-list
-    for (i=0; i<MAX_CHAN_PP; i++)                         
+    for (i=0; i<MAXFREQ; i++)                         
         {
         if (f->frequency[i] != NULLINT)
             t->frequency[i] &= f->frequency[i];
