@@ -85,7 +85,7 @@ struct c_block *cb_ptr;
     for (i=0; i<MAX_SAMP; i++)
         cb_ptr -> psamplers[i] = 0;
          
-    for (i=0; i<MAX_CHAN_PP; i++)
+    for (i=0; i<MAXFREQ; i++)
         {
         cb_ptr -> frequency[i] = DSB;        /* accept all frequency channels */
         cb_ptr -> pc_phase[i][0].ref = 0.0;
