@@ -97,6 +97,8 @@ init_tokens ()
     tokenize (OPTIMIZE_CLOSURE_, "optimize_closure", INT_PARAM)
     tokenize (PC_PHASE_L_,  "pc_phases_l",CHAN_PARAM)
     tokenize (PC_PHASE_R_,  "pc_phases_r",CHAN_PARAM)
+    tokenize (PC_PHASE_X_,  "pc_phases_x",CHAN_PARAM)
+    tokenize (PC_PHASE_Y_,  "pc_phases_y",CHAN_PARAM)
     tokenize (ION_WIN_,     "ion_win",    TWO_FLOAT_PARAM)
     tokenize (ION_NPTS_,    "ion_npts",   INT_PARAM)
     tokenize (INTERPOLATOR_,"interpolator",INT_PARAM)
@@ -105,6 +107,8 @@ init_tokens ()
     tokenize (STATION_DELAY_,"station_delay", FLOAT_PARAM)
     tokenize (PC_DELAY_L_,  "pc_delay_l", FLOAT_PARAM)
     tokenize (PC_DELAY_R_,  "pc_delay_r", FLOAT_PARAM)
+    tokenize (PC_DELAY_X_,  "pc_delay_x", FLOAT_PARAM)
+    tokenize (PC_DELAY_Y_,  "pc_delay_y", FLOAT_PARAM)
     tokenize (WEAK_CHANNEL_,"weak_channel", FLOAT_PARAM)
     tokenize (PC_AMP_HCODE_,"pc_amp_hcode", FLOAT_PARAM)
     tokenize (FMATCH_BW_PCT_,"fmatch_bw_pct", FLOAT_PARAM)
