@@ -40,8 +40,8 @@ void norm_fx (struct type_pass *pass,
     int sb, st, i, rev_i, j, l, m;
     static int nlags = 0;
     int ip, ips;
-    complex xp_spec[4*MAXLAG];
-    complex xcor[4*MAXLAG], S[4*MAXLAG], xlag[4*MAXLAG];
+    static complex xp_spec[4*MAXLAG];
+    static complex xcor[4*MAXLAG], S[4*MAXLAG], xlag[4*MAXLAG];
     complex z;
     double c_mag ();
     double factor, mean;
