@@ -46,8 +46,8 @@ void norm_xf (struct type_pass *pass,
     static int nlags = 0;
     int cosbits, coscor, sinbits, sincor;
     int ip, ips;
-    complex xp_spec[4*MAXLAG];
-    complex xcor[4*MAXLAG], S[4*MAXLAG], xlag[4*MAXLAG];
+    static complex xp_spec[4*MAXLAG];
+    static complex xcor[4*MAXLAG], S[4*MAXLAG], xlag[4*MAXLAG];
     complex z;
     double c_mag ();
     float  fraction, count_frac;
