@@ -91,7 +91,7 @@ struct c_block *cb_ptr;
     for (i=0; i<32; i++)
         cb_ptr -> source[i] = WILDCARD;
 
-    for (i=0; i<MAX_CHAN_PP; i++)
+    for (i=0; i<MAXFREQ; i++)
         {
         cb_ptr -> frequency[i] = NULLINT;
 
@@ -113,7 +113,7 @@ struct c_block *cb_ptr;
         cb_ptr -> delay_offs[i].rem = NULLFLOAT;
         }
 
-    for (i=0; i<2*MAX_CHAN_PP; i++)
+    for (i=0; i<2*MAXFREQ; i++)
         cb_ptr -> index[i]= NULLINT;
 
     return(0);
