@@ -49,7 +49,7 @@ int parser ()
         parsed_station,
         parsed_baseline[2],
         parsed_source[32],
-        parsed_codes[MAX_CHAN_PP],
+        parsed_codes[MAXFREQ],
         *psc,
         chan[2];
 
@@ -127,7 +127,7 @@ int parser ()
             {
             case CLEAR_FREQS:                /* clear all freq codes to start */
                for (cb_ptr=cond_start; cb_ptr!=NULL; cb_ptr=cb_ptr->cb_chain)
-                  for (i=0; i<MAX_CHAN_PP; i++)
+                  for (i=0; i<MAXFREQ; i++)
                      cb_ptr->frequency[i] = 0;
                                                 /* and then save token number */
                
@@ -220,14 +220,16 @@ int parser ()
                        if (cb_ptr -> baseline[1] == WILDCARD)
                            cb_ptr -> station_delay.ref = 1e-9 * float_values[tval];
                        }
-                   else if (toknum == PC_DELAY_L_)
+                   else if (toknum == PC_DELAY_L_
+                         || toknum == PC_DELAY_X_)
                        {
                        if (cb_ptr -> baseline[0] == WILDCARD)
                            cb_ptr -> pc_delay_l.rem = 1e-9 * float_values[tval];
                        if (cb_ptr -> baseline[1] == WILDCARD)
                            cb_ptr -> pc_delay_l.ref = 1e-9 * float_values[tval];
                        }
-                   else if (toknum == PC_DELAY_R_)
+                   else if (toknum == PC_DELAY_R_ 
+                         || toknum == PC_DELAY_Y_)
                        {
                        if (cb_ptr -> baseline[0] == WILDCARD)
                            cb_ptr -> pc_delay_r.rem = 1e-9 * float_values[tval];
@@ -268,7 +270,7 @@ int parser ()
                for (cb_ptr=cond_start; cb_ptr!=NULL; cb_ptr=cb_ptr->cb_chain)
                    if (toknum == INDEX_)
                        {
-                       if (nv == 2*MAX_CHAN_PP)
+                       if (nv == 2*MAXFREQ)
                            {
                            msg ("Too many index numbers",2);
                            return (-1);
@@ -279,7 +281,7 @@ int parser ()
                    else if (toknum == PC_PHASE_)  /* is this phase cal phase? */
                        {
                        i = fcode(parsed_codes[nv]);
-                       if (i<0 || i>MAX_CHAN_PP-1)
+                       if (i<0 || i>MAXFREQ-1)
                            {
                            msg ("Invalid phase cal frequency code",2);
                            return (-1);
@@ -315,10 +317,11 @@ int parser ()
                            }
                        }
 
-                   else if (toknum == PC_PHASE_L_)  // is this L/X/H phase cal phase?
+                   else if (toknum == PC_PHASE_L_
+                         || toknum == PC_PHASE_X_)  // is this L/X/H phase cal phase?
                        {
                        i = fcode(parsed_codes[nv]);
-                       if (i<0 || i>MAX_CHAN_PP-1)
+                       if (i<0 || i>MAXFREQ-1)
                            {
                            msg ("Invalid phase cal frequency code",2);
                            return (-1);
@@ -346,10 +349,11 @@ int parser ()
                            }
                        }
 
-                   else if (toknum == PC_PHASE_R_)  // is this R/Y/V phase cal phase?
+                   else if (toknum == PC_PHASE_R_
+                         || toknum == PC_PHASE_Y_)  // is this R/Y/V phase cal phase?
                        {
                        i = fcode(parsed_codes[nv]);
-                       if (i<0 || i>MAX_CHAN_PP-1)
+                       if (i<0 || i>MAXFREQ-1)
                            {
                            msg ("Invalid phase cal frequency code",2);
                            return (-1);
@@ -380,7 +384,7 @@ int parser ()
                    else if (toknum == PC_FREQ_)    /* is this phase cal freq? */
                        {
                        i = fcode(parsed_codes[nv]);
-                       if (i<0 || i>MAX_CHAN_PP-1)
+                       if (i<0 || i>MAXFREQ-1)
                            {
                            msg ("Invalid phase cal frequency code",2);
                            return (-1);
@@ -413,7 +417,7 @@ int parser ()
                    else if (toknum == PC_TONEMASK_)  // pcal tone exclusion mask?
                        {
                        i = fcode(parsed_codes[nv]);
-                       if (i<0 || i>MAX_CHAN_PP-1)
+                       if (i<0 || i>MAXFREQ-1)
                            {
                            msg ("Invalid pcal freq code in tonemask",2);
                            return (-1);
@@ -431,7 +435,7 @@ int parser ()
                    else if (toknum == GATES_) /*are these freq. switch gates? */
                        {
                        i = fcode(parsed_codes[nv/2]);
-                       if (i<0 || i>MAX_CHAN_PP-1)
+                       if (i<0 || i>MAXFREQ-1)
                            {
                            msg ("Invalid gates frequency code",2);
                            return (-1);
@@ -524,7 +528,7 @@ int parser ()
                    else if (toknum == DELAY_OFFS_) // is this a channel delay offset?
                        {
                        i = fcode(parsed_codes[nv]);
-                       if (i<0 || i>MAX_CHAN_PP-1)
+                       if (i<0 || i>MAXFREQ-1)
                            {
                            msg ("Invalid delay offset frequency code",2);
                            return (-1);
@@ -585,7 +589,7 @@ int parser ()
                    }
 
                i = fcode(chan[0]);                       /* get freq. array index */
-               if (i<0 || i>MAX_CHAN_PP-1 || sideband<0) /* trap error conditions */
+               if (i<0 || i>MAXFREQ-1 || sideband<0) /* trap error conditions */
                    {
                    msg ("Errant freq element: %c%c", 2, chan[0], chan[1]);
                    return (-1);
@@ -714,9 +718,9 @@ int parser ()
                break;
 
             case SAVE_CODES:
-               memset (parsed_codes,'\0',MAX_CHAN_PP);               /* pad with nulls */
+               memset (parsed_codes,'\0',MAXFREQ);               /* pad with nulls */
                i = strlen (char_values + tval);
-               i = (i > MAX_CHAN_PP) ? MAX_CHAN_PP : i;      /* move at most MAX_CHAN_PP chars */
+               i = (i > MAXFREQ) ? MAXFREQ : i;      /* move at most MAXFREQ chars */
 //               i = (i > 16) ? 16 : i;                /* move at most 16 chars */
                memcpy (parsed_codes, char_values + tval, i);
                break;
