@@ -119,6 +119,10 @@ struct token_struct
 #define MBD_ANCHOR_      89
 #define MODEL_           90
 #define SBD_             91
+#define PC_PHASE_X_      92
+#define PC_PHASE_Y_      93
+#define PC_DELAY_X_      94
+#define PC_DELAY_Y_      95
 
 
         /* Definitions of token categories */
