@@ -12,6 +12,8 @@
 
 #include <stdio.h>
 #include <math.h>
+#include <complex.h>
+#include <fftw3.h>
 #include "mk4_data.h"
 #include "param_struct.h"
 #include "pass_struct.h"
@@ -40,6 +42,7 @@ void pcalibrate (struct type_pass *pass,
         hipol,
         ndelpts,
         lsb;
+    static int do_once = TRUE;
 
     double minf,
            peak,
@@ -73,15 +76,16 @@ void pcalibrate (struct type_pass *pass,
     extern struct type_param param;
     extern struct type_status status;
                                     // function prototypes
-    double c_mag (complex), 
-           c_phase (complex);
-    complex c_zero (), 
-            c_add (complex, complex), 
-            c_mult (complex, complex), 
-            s_mult (complex, double),
-            c_mean (complex *, int),
-            c_exp (double);
     int parabola (double *, double, double, double *, double *, double *);
+    complex c_mean (complex *, int);
+    static fftw_plan fftplan;
+    
+                                    // pre-calculate fft quantities only once
+    if (do_once)
+        {
+        fftplan = fftw_plan_dft_1d (FFTSIZE, phasors, delay_fn, FFTW_FORWARD, FFTW_MEASURE);
+        do_once = FALSE;
+        }
  
     lowpol = 0;                     // default is to do both pols
     hipol = 1;
@@ -140,7 +144,7 @@ void pcalibrate (struct type_pass *pass,
           {
           ip = 0;
           nsubs = 0;
-          pc_adj[stn] = c_zero ();
+          pc_adj[stn] = 0.0;
           ndelpts = 0;
           del_avg = 0.0;
                                     // apply manual or offset pcal phase
@@ -153,7 +157,7 @@ void pcalibrate (struct type_pass *pass,
                 {                  // clear counters on sub-integration start
                 status.pcals_accum[stn] = 0.0;
                 for (i=0; i<MAX_PCF; i++)
-                    pc_avg[stn][i] = c_zero();
+                    pc_avg[stn][i] = 0.0;
                 ap_subint_start = ap;
                 }
 
@@ -171,8 +175,8 @@ void pcalibrate (struct type_pass *pass,
                                     // if in multitone mode, otherwise of single tone
             for (i=ilo; i<ihi; i++)
                 pc_avg[stn][i] = (ipol == 0) ?
-                    c_add (isd->phasecal_lcp[pass->pcinband[stn][fr][i]], pc_avg[stn][i]):
-                    c_add (isd->phasecal_rcp[pass->pcinband[stn][fr][i]], pc_avg[stn][i]);
+                    isd->phasecal_lcp[pass->pcinband[stn][fr][i]] + pc_avg[stn][i]:
+                    isd->phasecal_rcp[pass->pcinband[stn][fr][i]] + pc_avg[stn][i];
 
                                     // do calculations only at sub-integration end
                                     // or for last ap, when in multitone mode
@@ -181,9 +185,9 @@ void pcalibrate (struct type_pass *pass,
                                     // normalize the pcal phasors
               for (i=ilo; i<ihi; i++)
                   if (status.pcals_accum[stn] > 0.0)
-                      pc_avg[stn][i] = s_mult (pc_avg[stn][i], 1 / status.pcals_accum[stn]);
+                      pc_avg[stn][i] = pc_avg[stn][i] * 1 / status.pcals_accum[stn];
                   else 
-                      pc_avg[stn][i] = c_zero ();
+                      pc_avg[stn][i] = 0.0;
               
 
 
@@ -198,7 +202,7 @@ void pcalibrate (struct type_pass *pass,
                         msg ("stn %d subint ap %d..%d tone %d freq %10.f pc phasor %7.2f %7.2f",
                         0, stn, ap_subint_start, ap, i,
                         fdata->pc_freqs[stn][pass->pcinband[stn][fr][i]],
-                        1e3 * c_mag(pc_avg[stn][i]), 180.0 / M_PI * c_phase(pc_avg[stn][i]));
+                        1e3 * cabs (pc_avg[stn][i]), 180.0 / M_PI * carg (pc_avg[stn][i]));
 
                                     // find lowest (USB) or highest (LSB) tone frequency
                 minf = 1e12;
@@ -221,25 +225,25 @@ void pcalibrate (struct type_pass *pass,
 
                                     // pad with zeroes to increase sampling of transform
                 for (i=0; i<FFTSIZE; i++)
-                    phasors[i] = c_zero ();
+                    phasors[i] = 0.0;
                                     // fill array with complex tone values
                 for (i=0; i<pass->npctones; i++)
                     if (pass->pcinband[stn][fr][i] >= 0)
                         phasors[index[i]] = pc_avg[stn][i];
                                     // fft to delay space
-                FFT1 (phasors, FFTSIZE, 1, delay_fn, 1);
+                fftw_execute (fftplan);
                                     // find peak of fft
                 peak = -1.0;
                 for (i=0; i<FFTSIZE; i++)
-                    if (c_mag (delay_fn[i]) > peak)
+                    if (cabs (delay_fn[i]) > peak)
                         {
-                        peak = c_mag (delay_fn[i]);
+                        peak = cabs (delay_fn[i]);
                         indpeak = i;
                         }
                                     // interpolate to optimal value
                 y[1] = peak;
-                y[0] = c_mag (delay_fn[(indpeak+FFTSIZE-1)%FFTSIZE]);
-                y[2] = c_mag (delay_fn[(indpeak+FFTSIZE+1)%FFTSIZE]);
+                y[0] = cabs (delay_fn[(indpeak+FFTSIZE-1)%FFTSIZE]);
+                y[2] = cabs (delay_fn[(indpeak+FFTSIZE+1)%FFTSIZE]);
                 parabola (y, -1.0, 1.0, &ymax, &ampmax, q);
 
                                     // DC is in 0th element
@@ -264,24 +268,24 @@ void pcalibrate (struct type_pass *pass,
                             deltaf = -deltaf;
                         theta = 2.0 * M_PI * delay * deltaf;
 
-                        rotval[i] = c_mult (pc_avg[stn][i], c_exp (theta));
+                        rotval[i] = pc_avg[stn][i] * cexp (I * theta);
                         msg ("stn %d chan %02d pol %d ap %02d-%02d tone %02d "
                              "rotated pcal phasor %7.2f %7.2f", 0, 
                              stn, fr, ipol, ap_subint_start, ap, i,
-                             1e3 * c_mag(rotval[i]), 180.0 / M_PI * c_phase(rotval[i]));
+                             1e3 * cabs(rotval[i]), 180.0 / M_PI * carg (rotval[i]));
                         nin++;
                         }
                 if (nin >  0)       // use mean iff it exists
                     pc_sub[stn] = c_mean (rotval, nin);
                 else
-                    pc_sub[stn] = c_zero ();
+                    pc_sub[stn] = 0.0;
                                     // write this value into all ap's of sub-int.
                 for (kap=ap_subint_start; kap<=ap; kap++)
                     {
                     kdatum = fdata->data + kap;
                     ksd = (stn == 0) ? &(kdatum->ref_sdata) : &(kdatum->rem_sdata);
                                     // also rotate by offsets and ionosphere
-                    ksd->mt_pcal[ipol] = c_mult (pc_sub[stn], c_exp(delta_phase[stn]));
+                    ksd->mt_pcal[ipol] = pc_sub[stn] * cexp(I * delta_phase[stn]);
                                     // invert delay sign when derived from lsb tones
                     ksd->mt_delay[ipol] = lsb ? -delay : delay;
                                     // keep track of avg delay for ch/stn/pol
@@ -289,7 +293,7 @@ void pcalibrate (struct type_pass *pass,
                     ndelpts++;
                     }
                                     // maintain a running total
-                pc_adj[stn] = c_add (pc_sub[stn], pc_adj[stn]);
+                pc_adj[stn] = pc_sub[stn] + pc_adj[stn];
                 nsubs++;
                 }                   // bottom of if multitone
               }                     // end of sub-integration calculation block
@@ -298,22 +302,21 @@ void pcalibrate (struct type_pass *pass,
                                     // find average pcal phasor for multitone
           if (param.pc_mode[stn] == MULTITONE)
               {
-              pc_adj[stn] = s_mult (pc_adj[stn], 1.0 / nsubs);
+              pc_adj[stn] = pc_adj[stn] * 1.0 / nsubs;
               }
           else                      // if not multitone, just copy in phasor from
               {                     // single tone, and continue on with next freq
               if (param.pc_mode[stn] != MANUAL)
                   pc_adj[stn] = pc_avg[stn][ilo];
               else
-                  {                 // manual pcal - set to unit amp, zero phase
-                  pc_adj[stn].re = 1.0;
-                  pc_adj[stn].im = 0.0;
-                  }
+                                    // manual pcal - set to unit amp, zero phase
+                  pc_adj[stn] = 1.0 + 0.0 * I;
+                  
               msg ("non-multitone pcal phasor %7.2f %7.2f", -1, 
-                      1e3 * c_mag (pc_adj[stn]), 180.0 / M_PI * c_phase (pc_adj[stn]));
+                      1e3 * cabs (pc_adj[stn]), 180.0 / M_PI * carg (pc_adj[stn]));
               }
                                     // make copies of amplitude and phase
-          status.pc_meas[fr][stn][ipol] = c_phase (pc_adj[stn]);
+          status.pc_meas[fr][stn][ipol] = carg (pc_adj[stn]);
           status.pc_phase[fr][stn][ipol] = status.pc_meas[fr][stn][ipol];
                                     // store delay average per channel, stn, and pol
           status.pc_delay[fr][stn][ipol] = del_avg / ndelpts;
@@ -321,10 +324,24 @@ void pcalibrate (struct type_pass *pass,
           if (param.pc_mode[stn] != MULTITONE)
               status.pc_phase[fr][stn][ipol] += delta_phase[stn];
 
-          status.pc_amp[fr][stn][ipol] = c_mag (pc_adj[stn]);
+          status.pc_amp[fr][stn][ipol] = cabs (pc_adj[stn]);
           msg ("chan %d stn %d ipol %d pc_amp %6.2f pc_phase %7.2f\n", 0,
                fr, stn, ipol, 1e3 * status.pc_amp[fr][stn][ipol], 
                180.0 / M_PI * status.pc_phase[fr][stn][ipol]);
           }                         // end of polarizaton loop
         }                           // bottom of stn = 0..1 loop
     }
+
+
+// return mean of n complex numbers, z
+complex c_mean (complex *z, int n)
+    {
+    int i;
+    complex sum;
+
+    sum = 0.0;
+    for (i=0; i<n; i++)
+        sum = sum + *(z+i);
+    sum = sum / n;
+    return (sum);
+    }
